# Visualization Functions

Plotly chart generation functions.

## CEFR Charts

::: fundedness.viz.waterfall.create_cefr_waterfall

## Simulation Charts

::: fundedness.viz.fan_chart.create_fan_chart

::: fundedness.viz.survival.create_survival_curve

::: fundedness.viz.histogram.create_time_distribution_histogram

## Comparison Charts

::: fundedness.viz.comparison.create_strategy_comparison_chart

## Sensitivity Charts

::: fundedness.viz.tornado.create_tornado_chart
